@@ -74,9 +74,8 @@ setMethodS3("rowWeightedMedians", "matrix", function(x, w=NULL, na.rm=FALSE, ...
   if (hasWeights) {
     # Allocate results
     m <- nrow(x);
-    res <- double(m);
     if (m == 0L)
-      return(res);
+      return(double(0L));
 
     # Standardize weights to sum to one.
     w <- w / sum(w, na.rm=na.rm);
@@ -84,6 +83,8 @@ setMethodS3("rowWeightedMedians", "matrix", function(x, w=NULL, na.rm=FALSE, ...
     res <- apply(x, MARGIN=1L, FUN=function(x) {
       weightedMedian(x, w=w, na.rm=na.rm, ...);
     });
+
+    w <- NULL; # Not needed anymore
   } else {
     res <- rowMedians(x, na.rm=na.rm);
   }
@@ -115,9 +116,8 @@ setMethodS3("colWeightedMedians", "matrix", function(x, w=NULL, na.rm=FALSE, ...
   if (hasWeights) {
     # Allocate results
     m <- ncol(x);
-    res <- double(m);
     if (m == 0L)
-      return(res);
+      return(double(0L));
 
     # Standardize weights to sum to one.
     w <- w / sum(w, na.rm=na.rm);
@@ -125,6 +125,8 @@ setMethodS3("colWeightedMedians", "matrix", function(x, w=NULL, na.rm=FALSE, ...
     res <- apply(x, MARGIN=2L, FUN=function(x) {
       weightedMedian(x, w=w, na.rm=na.rm, ...);
     });
+
+    w <- NULL; # Not needed anymore
   } else {
     res <- colMedians(x, na.rm=na.rm);
   }
@@ -135,6 +137,8 @@ setMethodS3("colWeightedMedians", "matrix", function(x, w=NULL, na.rm=FALSE, ...
 
 ##############################################################################
 # HISTORY:
+# 2013-11-23
+# o MEMORY: Now (col|row)WeightedMedians() clean out allocated objects sooner.
 # 2012-04-16
 # o Now {col|row}WeightedMedians() no longer require aroma.light, because
 #   weightedMedian() is now in this package.
