@@ -3,8 +3,8 @@
   binMeans_<L|R>(...)
 
  GENERATES:
-  SEXP binMeans_L(SEXP y, SEXP x, SEXP bx, SEXP retCount)
-  SEXP binMeans_R(SEXP y, SEXP x, SEXP bx, SEXP retCount)
+  void binMeans_L(double *y, R_xlen_t ny, double *x, R_xlen_t nx, double *bx, R_xlen_t nbins, double *ans, int *count)
+  void binMeans_R(double *y, R_xlen_t ny, double *x, R_xlen_t nx, double *bx, R_xlen_t nbins, double *ans, int *count)
 
  Arguments:
    The following macros ("arguments") should be defined for the
@@ -13,11 +13,7 @@
 
  Copyright Henrik Bengtsson, 2012-2013
  **************************************************************************/
-/* Include R packages */
-#include <Rdefines.h>
-#include <R.h>
-#include <R_ext/Error.h>
-
+#include "types.h"
 
 #if BIN_BY == 'L'   /* [u,v) */
   #define METHOD_NAME binMeans_L
@@ -30,32 +26,17 @@
 #endif
 
 
-SEXP METHOD_NAME(SEXP y, SEXP x, SEXP bx, SEXP retCount) {
-  int ny = Rf_length(y), nx = Rf_length(x), nb = Rf_length(bx)-1;
-  double *yp = REAL(y), *xp = REAL(x), *bxp = REAL(bx);
-  SEXP ans = PROTECT(NEW_NUMERIC(nb));
-  double *ansp = REAL(ans);
-  int retcount = LOGICAL(retCount)[0];
-  SEXP count = NULL;
-  int *countp = NULL;
-  int ii = 0, jj = 0, n = 0, iStart=0;
-  double sum = 0.0;
-
-  // Assert same lengths of 'x' and 'y'
-  if (ny != nx) {
-    error("Argument 'y' and 'x' are of different lengths: %d != %d", ny, nx);
-  }
-
-  if (retcount) {
-    count = PROTECT(NEW_INTEGER(nb));
-    countp = INTEGER(count);
-  }
+void METHOD_NAME(double *y, R_xlen_t ny, double *x, R_xlen_t nx, double *bx, R_xlen_t nbins, double *ans, int *count) {
+  R_xlen_t ii = 0, jj = 0, iStart=0;
+  R_xlen_t n = 0;
+  LDOUBLE sum = 0.0;
+  int warn = 0;
 
   // Count?
-  if (nb > 0) {
+  if (nbins > 0) {
 
     // Skip to the first bin
-    while ((iStart < nx) && IS_PART_OF_FIRST_BIN(xp[iStart], bxp[0])) {
+    while ((iStart < nx) && IS_PART_OF_FIRST_BIN(x[iStart], bx[0])) {
       ++iStart;
     }
 
@@ -63,10 +44,20 @@ SEXP METHOD_NAME(SEXP y, SEXP x, SEXP bx, SEXP retCount) {
     for (ii = iStart; ii < nx; ++ii) {
 
       // Skip to a new bin?
-      while (IS_PART_OF_NEXT_BIN(xp[ii], bxp[jj+1])) {
+      while (IS_PART_OF_NEXT_BIN(x[ii], bx[jj+1])) {
         // Update statistic of current bin?
-        if (retcount) { countp[jj] = n; }
-        ansp[jj] = n > 0 ? sum / n : R_NaN;
+        if (count) {
+          /* Although unlikely, with long vectors the count for a bin
+             can become greater than what is possible to represent by
+             an integer.  Detect and warn about this. */
+          if (n > R_INT_MAX) {
+            warn = 1;
+            count[jj] = R_INT_MAX;
+          } else {
+            count[jj] = n;
+          }
+	}
+        ans[jj] = n > 0 ? sum / n : R_NaN;
         sum = 0.0;
         n = 0;
 
@@ -74,44 +65,49 @@ SEXP METHOD_NAME(SEXP y, SEXP x, SEXP bx, SEXP retCount) {
         ++jj;
 
         // No more bins?
-        if (jj >= nb) {
+        if (jj >= nbins) {
           // Make the outer for-loop to exit...
           ii = nx - 1;
-          // ...but correct for the fact that the yp[nx-1] point will
+          // ...but correct for the fact that the y[nx-1] point will
           // be incorrectly added to the sum.  Doing the correction
-          // here avoids an if (ii < nx) sum += yp[ii] below.
-          sum -= yp[ii];
+          // here avoids an if (ii < nx) sum += y[ii] below.
+          sum -= y[ii];
           break;
         }
       }
 
       // Sum and count
-      sum += yp[ii];
+      sum += y[ii];
       ++n;
     }
 
     // Update statistic of the last bin?
-    if (jj < nb) {
-      if (retcount) countp[jj] = n;
-      ansp[jj] = n > 0 ? sum / n : R_NaN;
+    if (jj < nbins) {
+      if (count) {
+        /* Although unlikely, with long vectors the count for a bin
+           can become greater than what is possible to represent by
+           an integer.  Detect and warn about this. */
+        if (n > R_INT_MAX) {
+          warn= 1;
+          count[jj] = R_INT_MAX;
+        } else {
+          count[jj] = n;
+	}
+      }
+      ans[jj] = n > 0 ? sum / n : R_NaN;
 
       // Assign the remaining bins to zero counts and missing mean values
-      while (++jj < nb) {
-        ansp[jj] = R_NaN;
-        if (retcount) countp[jj] = 0;
+      while (++jj < nbins) {
+        ans[jj] = R_NaN;
+        if (count) count[jj] = 0;
       }
     }
 
-  } // if (nb > 0)
+  } // if (nbins > 0)
 
-
-  if (retcount) {
-    setAttrib(ans, install("count"), count);
-    UNPROTECT(1); // 'count'
+  if (warn) {
+    warning("Integer overflow. Detected one or more bins with a count that is greater than what can be represented by the integer data type. Setting count to the maximum integer possible (.Machine$integer.max = %d). The bin mean is still correct.", R_INT_MAX);
   }
-  UNPROTECT(1); // 'ans'
-
-  return ans;
 }
 
 
@@ -125,6 +121,10 @@ SEXP METHOD_NAME(SEXP y, SEXP x, SEXP bx, SEXP retCount) {
 
 /***************************************************************************
  HISTORY:
+2014-11-07 [HB]
+  o ROBUSTNESS: Added protection for integer overflow in bin counts.
+2014-11-06 [HB]
+  o CLEANUP: Moving away from R data types in low-level C functions.
 2014-10-01 [HB]
   o BUG FIX: binMeans() returned 0.0 instead of NA_real_ for empty bins.
 2014-04-04 [HB]
